#
# spec file for package libsigrok
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libsigrok
Version:        0.3.0
%define libname %{name}2
Release:        8.1
Summary:        Basic API for talking to logic analyzer hardware
License:        GPL-3.0+
Group:          Productivity/Scientific/Electronics
Url:            http://sigrok.org
Source0:        http://sigrok.org/download/source/libsigrok/%{name}-%{version}.tar.gz
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  check-devel >= 0.9.4
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel >= 2.32.0
BuildRequires:  libftdi1-devel >= 0.16
BuildRequires:  libserialport-devel >= 0.1.0
BuildRequires:  libtool
BuildRequires:  libudev-devel
BuildRequires:  libusb-1_0-devel
BuildRequires:  libzip-devel >= 0.10
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

libsigrok is a shared library written in C which provides the basic API
for talking to logic analyzer hardware and reading/writing the acquired data
into various input/output file formats.

%package     -n %{libname}
Summary:        Basic API for talking to logic analyzer hardware
Group:          System/Libraries
Requires:       %{name}-data >= %{version}

%description -n %{libname}
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

libsigrok is a shared library written in C which provides the basic API
for talking to logic analyzer hardware and reading/writing the acquired data
into various input/output file formats.

%package        data
Summary:        Basic API for talking to logic analyzer hardware
Group:          Productivity/Scientific/Electronics
BuildArch:      noarch

%description    data
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

libsigrok is a shared library written in C which provides the basic API
for talking to logic analyzer hardware and reading/writing the acquired data
into various input/output file formats.

%package        devel
Summary:        Basic API for talking to logic analyzer hardware
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

libsigrok is a shared library written in C which provides the basic API
for talking to logic analyzer hardware and reading/writing the acquired data
into various input/output file formats.

%prep
%setup -q

%build
# libusb 1.0.16 is not really required
sed -i 's/libusb-1.0 >= 1.0.16/libusb-1.0 >= 1.0.9/' configure.ac
autoreconf

CFLAGS=-fno-strict-aliasing \
%configure \
        --disable-static \
        --enable-fx2lafw
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print

%define action TAG+="uaccess"
install -d -m 755 %{buildroot}%{_udevrulesdir}
sed 's/MODE="664".*/%{action}/' contrib/z60_libsigrok.rules \
    > %{buildroot}%{_udevrulesdir}/50-libsigrok.rules

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root,-)
%{_libdir}/*.so.*

%files data
%defattr(-,root,root,-)
%{_udevrulesdir}/*

%files devel
%defattr(-,root,root,-)
%doc COPYING README HACKING NEWS
%{_libdir}/*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*

%changelog
* Wed Aug  6 2014 dmitry_r@opensuse.org
- Move udev rules to libsigrok-data due to SLPP
* Mon Jun  2 2014 bugs@vdm-design.de
- Sync spec file with libsigrok.spec from rmax
* Fri May 30 2014 bugs@vdm-design.de
- Update to version 0.3.0
  * New supported hardware:
  - Logic analyzers:
  - ChronoVu LA16
  - Sysclk LWLA1034
  - Oscilloscopes:
  - Agilent DSO1000 series
  - Hameg HMO compact series
  - Rigol DS2000 series
  - Rigol VS5000 series
  - Multimeters:
  - BBC Goerz Metrawatt M2110
  - Brymen BM869
  - Fluke 189
  - Gossen Metrawatt MetraHIT 1x/2x series
  - Tenma 72-7745/72-7750 (rebadged UNI-T UT60E/UT60G)
  - UNI-T UT60G/UT61B/UT61C
  - V&A VA40B
  - Voltcraft M-3650CR/ME-42
  - Thermometers:
  - APPA 55II
  - Programmable power supplies:
  - Atten PPS3000 series
  - Conrad DIGI 35 CPU
  * Most important changes:
  - We added support for channel groups (multiple channels of the device, that share some properties and are configured together).
  - There's a generic SCPI backend now that drivers can use, supporting various transports: serial ports, USBTMC, TCP/RAW, TCP/Rigol, VXI, and librevisa.
  - The session file format (*.sr) has changed and its version was bumped to 2.
  - There's improved Windows support now for serial port and USB based devices, though it's partially still experimental! Please checkout the current list of known Windows issues, since there are some problems e.g. with the popular FX2 based devices (bug #343) and the Openbench Logic Sniffer (bug #205). Feedback, bug reports and patches are highly welcome!
  - Various API improvements were also done, to allow for some of the new features and to ease future extendability. You can take a look at the API docs for more details.
* Mon Dec 16 2013 bugs@vdm-design.de
- Update to version 0.2.2
  * New supported hardware:
  - Logic analyzers:
  - Saleae Logic16
  - Thermometers:
  - Center 309
  - UNI-T UT325
  - Voltcraft K204
  - Multimeters:
  - ISOTECH IDM103N
  - Metex M-4650CR
  - Norma DM950
  - Voltcraft M-4650CR
  - Energy meters:
  - EDF Teleinfo
  * New config keys:
  - SR_CONF_VOLTAGE_THRESHOLD
  - SR_CONF_EXTERNAL_CLOCK
  - SR_CONF_SWAP
  - SR_CONF_ENERGYMETER
  * New config info types:
  - SR_T_DOUBLE_RANGE
  * New units:
  - SR_UNIT_REVOLUTIONS_PER_MINUTE
  - SR_UNIT_VOLT_AMPERE
  - SR_UNIT_WATT
  - SR_UNIT_WATT_HOUR
  * New input modules:
  - csv (comma-separated values)
  * Bump required libzip version to >= 0.10.
  * uni-t-dmm: This driver now requires the specification of the USB VID/PID
  of the cable that is used. Example for sigrok-cli:
  - Old: sigrok-cli --driver voltcraft-vc820 ...
  - New: sigrok-cli --driver voltcraft-vc820:conn=1a86.e008 ...
  * openbench-logic-sniffer:
  - Initial test pattern support (SR_CONF_PATTERN_MODE).
  - Initial external clock support (SR_CONF_EXTERNAL_CLOCK).
  - Initial channel swap support (SR_CONF_SWAP).
  - Various minor fixes and improvements.
  * When a frontend adds a device instance to a running session, start
  acquisition on it. This helps with the collectd use-case where devices
  can be removed and added dynamically while a session is running.
  * rigol-ds1xx2: Support newer Linux kernels with USBTMC in /sys/class/usbmisc.
  * rigol-ds1xx2: Also detect the Rigol DS1152E/DS1152D.
  * agilent-dmm: Fix a segfault happening in certain cases.
  * output/analog: Support all currently known MQFLAGs.
  * Fix a minor compile issue due to an incorrect #include.
  * Fix two compile issues on FreeBSD (bug #185).
  * es519xx: New generic parser for various Cyrustek DMM ICs.
  * es51922/fs9721/fs9922/metex14: Use diode MQFLAG (bug #141).
  * voltcraft-vc830: Fix diode mode handling (bug #142).
  * Add the missing HACKING file to the tarball.
  * README.devices: Updates/notes for newly added devices.
* Sun Aug 11 2013 bugs@vdm-design.de
- Update to version 0.2.1
  * New supported hardware:
  - Logic analyzers:
  - IKALOGIC Scanalogic-2
  - IKALOGIC ScanaPLUS
  - Sound level meters:
  - CEM DT-8852
  - Kecheng KC-330B
  - Multimeters:
  - UNI-T UT60A
  - UNI-T UT60E
  - Voltcraft M-3650D
  - Voltcraft VC-830
  * Drop the Tecpel DMM-8060 (doesn't have PC connectivity).
  * New config keys:
  - SR_CONF_SPL_WEIGHT_FREQ
  - SR_CONF_SPL_WEIGHT_TIME
  - SR_CONF_SPL_MEASUREMENT_RANGE
  - SR_CONF_HOLD_MIN
  - SR_CONF_HOLD_MAX
  - SR_CONF_POWER_OFF
  - SR_CONF_DATA_SOURCE
  * New config info types:
  - SR_T_UINT64_RANGE
  * New error codes:
  - SR_ERR_TIMEOUT
  * Always link against libm, the math library (bug #115).
  * Fix a bug in sr_si_string_u64() at al (bug #73).
  * output/csv: Fix incorrect probe order.
  * alsa: Fix a double-free issue (bug #129).
  * zeroplus-logic-cube: Fix a bug in the driver cleanup code.
  * ikalogic-scanalogic2: Use GET_REPORT (bug #130).
  * uni-t-dmm: Fix a bug breaking the UNI-T UT61E (bug #136).
  * Various internal consistency fixes and code cleanups.
  * Improved Doxygen documentation.
  * Fixed various memory leaks.
* Wed Jan 30 2013 max@suse.com
- Install udev rules to give local users access to sigrok devices.
* Wed Jan 16 2013 max@suse.com
- Initial build from cvs.
